package com.ruoyi.set.service;

import java.util.List;
import com.ruoyi.set.domain.SetRegion;

/**
 * 行政区域Service接口
 *
 * @author LCL
 * @date 2023-07-12
 */
public interface ISetRegionService
{
    /**
     * 查询行政区域
     *
     * @param id 行政区域主键
     * @return 行政区域
     */
    public SetRegion selectSetRegionById(Long id);

    /**
     * 查询行政区域列表
     *
     * @param setRegion 行政区域
     * @return 行政区域集合
     */
    public List<SetRegion> selectSetRegionList(SetRegion setRegion);

    /**
     * 新增行政区域
     *
     * @param setRegion 行政区域
     * @return 结果
     */
    public int insertSetRegion(SetRegion setRegion);

    /**
     * 修改行政区域
     *
     * @param setRegion 行政区域
     * @return 结果
     */
    public int updateSetRegion(SetRegion setRegion);

    /**
     * 批量删除行政区域
     *
     * @param ids 需要删除的行政区域主键集合
     * @return 结果
     */
    public int deleteSetRegionByIds(Long[] ids);

    /**
     * 删除行政区域信息
     *
     * @param id 行政区域主键
     * @return 结果
     */
    public int deleteSetRegionById(Long id);

    /**
     * 查询行政区域列表-省
     *
     * @return 行政区域集合
     */
    public List<SetRegion> selectRegionProvinceList();

    /**
     * 查询行政区域列表-市或区县
     *
     * @param id 行政区域主键ID
     * @return 行政区域集合
     */
    public List<SetRegion> selectRegionCityOrAreaList(Integer id);
}
